@@ -1,6 +1,12 @@
+-- | This module contains functions to create option descriptions, together
+-- with their argument types.
 module System.Console.Argument
   (
-    Type (Type,parser,name,defaultValue)
+  -- * Option descriptions
+    Option
+  , option
+
+  , Type (Type,parser,name,defaultValue)
   
   -- * Argument types
   , optional
@@ -10,11 +16,7 @@ module System.Console.Argument
   , file
   , device
   , natural
-  , integer
-  
-  -- * Option descriptions
-  , Option
-  , option
+  , integer  
   ) where
 
 
